AnsightDebugSnapshot class

Constructors

AnsightDebugSnapshot({required bool initialized, required bool active, required bool sessionOpen, required int metricsRecorded, required int eventsRecorded, required int registeredTools, required List<AnsightChannel> channels, required AnsightHostConnectionStatus connectionStatus, String? lifecycleState, int? touchesRecorded, int? touchesCaptured, int? touchesSent, int? executableTools, String? sessionMessage, AnsightRecordedMetric? lastMetric, AnsightRecordedEvent? lastEvent, AnsightJson data = const <String, Object?>{}})
const
AnsightDebugSnapshot.fromJson(AnsightJson json)
factory

Properties

active bool
final
channels List<AnsightChannel>
final
connectionStatus AnsightHostConnectionStatus
final
data AnsightJson
final
eventsRecorded int
final
executableTools int?
final
hashCode int
The hash code for this object.
no setterinherited
initialized bool
final
lastEvent AnsightRecordedEvent?
final
lastMetric AnsightRecordedMetric?
final
lifecycleState String?
final
metricsRecorded int
final
registeredTools int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionMessage String?
final
sessionOpen bool
final
touchesCaptured int?
final
touchesRecorded int?
final
touchesSent int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited