AnsightHostAutoProbeOptions class

Constructors

AnsightHostAutoProbeOptions({bool enabled = true, int initialDelayMilliseconds = 1000, int probeIntervalMilliseconds = 5000, int reconnectDelayMilliseconds = 10000, String? clientName})
const

Properties

clientName String?
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
initialDelayMilliseconds int
final
probeIntervalMilliseconds int
final
reconnectDelayMilliseconds int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() AnsightJson
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited