AnsightNetworkBody class

Constructors

AnsightNetworkBody({String? contentType, required String encoding, required String data, required int capturedBytes, int? totalBytes, required bool truncated})
const

Properties

capturedBytes int
final
contentType String?
final
data String
final
encoding String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBytes int?
final
truncated bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() AnsightJson
toMessage() → AnsightNetworkBodyMessage
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited