AnsightRecordedMetric class

Constructors

AnsightRecordedMetric({required int value, required int channel, DateTime? recordedAtUtc, int? sequence, AnsightJson data = const <String, Object?>{}})
const
AnsightRecordedMetric.fromJson(AnsightJson json)
factory

Properties

channel int
final
data AnsightJson
final
hashCode int
The hash code for this object.
no setterinherited
recordedAtUtc DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int?
final
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited