AnsightToolResult class

Constructors

AnsightToolResult({required bool success, String? message, String? errorCode, Object? result})
const
AnsightToolResult.failure({required String? message, String? errorCode, Object? result})
const
AnsightToolResult.success({Object? result, String? message})
const

Properties

errorCode String?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
result Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() AnsightJson
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited