AnsightChannel class
Constructors
- AnsightChannel({required int id, required String name, String? unit, String type = 'custom', String? colorHex, String? source, String? group, String? kind})
-
const
- AnsightChannel.fromJson(AnsightJson json)
-
factory
Properties
- colorHex → String?
-
final
- group → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- kind → String?
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String?
-
final
- type → String
-
final
- unit → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → AnsightJson -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited