AnsightHostConnectionCapabilities class
Constructors
- AnsightHostConnectionCapabilities({required bool canConnectUsingSavedConfig, required bool canConnectUsingBundledConfig, required bool canChooseConfigFile, required bool canScanConfigQrCode, required bool canClearSavedConfigs, AnsightJson data = const <String, Object?>{}})
-
const
- AnsightHostConnectionCapabilities.fromJson(AnsightJson json)
-
factory
Properties
- canChooseConfigFile → bool
-
final
- canClearSavedConfigs → bool
-
final
- canConnectUsingBundledConfig → bool
-
final
- canConnectUsingSavedConfig → bool
-
final
- canScanConfigQrCode → bool
-
final
- data → AnsightJson
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited