AnsightRemoteToolsOptions class
Constructors
- AnsightRemoteToolsOptions({bool? visualTree, AnsightFileSystemToolsOptions? fileSystem, AnsightDatabaseToolsOptions? database, AnsightPreferencesToolsOptions? preferences, AnsightReflectionToolsOptions? reflection, AnsightSecureStorageToolsOptions? secureStorage})
-
const
Properties
- database → AnsightDatabaseToolsOptions?
-
final
- fileSystem → AnsightFileSystemToolsOptions?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- preferences → AnsightPreferencesToolsOptions?
-
final
- reflection → AnsightReflectionToolsOptions?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secureStorage → AnsightSecureStorageToolsOptions?
-
final
- visualTree → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → AnsightJson -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited